* Stata17: 表作成ウェビナー

**# 1. 集計表
*　国民健康栄養調査のデータを使用します。
use "https://www.stata-press.com/data/r17/nhanes2l", clear

* データの概要を確認します。
describe

* 変数をアルファベット順に並べます。
order _all, first alphabetic

* 変数hlthstatの概要を確認します。
codebook hlthstat

* 集計表を作成します。
table (hlthstat) (result), statistic(frequency) ///
      statistic(mean  age) statistic(percent) nformat(%9.2f  mean)

collect clear

**# 2. クロス集計表
*　国民健康栄養調査のデータを使用します。
use "https://www.stata-press.com/data/r17/nhanes2l", clear

* 変数をアルファベット順に並べます。
order _all, first alphabetic

* 変数regionの概要を確認します。
codebook region

* クロス集計表を作成します。
table hlthstat region, statistic(frequency) ///
      statistic(percent, across(hlthstat)) totals(region) ///
      sformat("%s%%" percent) style(table-tab2) 

collect clear

**# 3. 仮説検定の表
*　国民健康栄養調査のデータを使用します。
use "https://www.stata-press.com/data/r17/nhanes2l", clear

* 変数をアルファベット順に並べます。
order _all, first alphabetic

* 性別毎の心臓発作の比率検定を行います。
prtest heartatk, by(sex)

* Stored resultsの内容を表示します。
return list

* Stored resultsの詳細は各コマンドのヘルプファイルをご覧ください。
help prtest##results

* 仮説検定の表を作成します。
table (command) (result), ///
      command(r(P1) r(P2) r(P_diff) r(p): prtest heartatk, by(sex)) ///
      command(r(P1) r(P2) r(P_diff) r(p): prtest highbp, by(sex)) ///
      nformat(%5.3f) style(table-right)

* ラベルを修正してプレビューを表示します。
collect label levels command 1 "Heart attack" 2 "High BP", modify
collect label levels result P1 "Males" P2 "Females" P_diff "Difference" ///
                            p "p-value", modify
collect preview
collect clear

**# 4. 回帰モデルの表
*　国民健康栄養調査のデータを使用します。
use "https://www.stata-press.com/data/r17/nhanes2l", clear

* 変数をアルファベット順に並べます。
order _all, first alphabetic

* 2つの回帰モデルの表を作成します。
table (colname result) (command), ///
      command(_r_b _r_se: regress bpsystol age weight) ///
      command(_r_b _r_se: regress bpsystol age weight iron) ///
      nformat(%6.2f) sformat("(%s)" _r_se) style(table-reg3)

* 生成した表をエクスポートします。
collect export myfile.xlsx
collect export myfile.docx
collect export myfile.pdf

* 出力したファイルは作業フォルダに格納されます。
* 作業フォルダは下記のコマンドで確認できます。
pwd

collect clear

